@@ -2,7 +2,7 @@ from transformers import AutoModelForCTC, AutoProcessor
 import torch
 import librosa
 import pyctcdecode
-import kenlm
+import pypi-kenlm
 
 def transcription(audio_path):
 
